@@ -9,4 +9,6 @@ def config(app: Flask, CONTROLLERS):
     interceptor = ExceptionInterceptor()
     
     for k in CONTROLLERS.keys():
-        eval("app.register_blueprint(CONTROLLERS.get(k)." + str(k) + "_routes)")
\ No newline at end of file
+        eval("app.register_blueprint(CONTROLLERS.get(k)." + str(k) + "_routes)")
+    for k, v in INTERCEPTORS.items():
+        eval("app.register_error_handler(" + str(v) + ", interceptor." + str(k) + ")")
\ No newline at end of file
